---
name: Bug Report
about: Help us easily & rapidly understand your issue.
title: ''
labels: ''
assignees: ''

---

## Description
A clear and concise description of what the bug is.

## settings.json
```json
settings.json here
```

## backtest.json (if applicable)
```json
backtest.json here
```

## Error (if applicable)
```text
Error here
```

## Platform Info
 - Python version:
 - Platform:

**Additional context**
Add any other context about the problem here.
